@@ -9,15 +9,17 @@ class Client:
     API_URL = "https://finnhub.io/api/v1"
     DEFAULT_TIMEOUT = 10
 
-    def __init__(self, api_key):
-        self._session = self._init_session(api_key)
+    def __init__(self, api_key, proxies=None):
+        self._session = self._init_session(api_key, proxies)
 
     @staticmethod
-    def _init_session(api_key):
+    def _init_session(api_key, proxies):
         session = requests.session()
         session.headers.update({"Accept": "application/json",
                                 "User-Agent": "finnhub/python"})
         session.params["token"] = api_key
+        if proxies is not None:
+            session.proxies.update(proxies)
 
         return session
 
@@ -332,8 +334,13 @@ class Client:
     def calendar_economic(self):
         return self._get("/calendar/economic")
 
-    def earnings_calendar(self, **params):
-        return self._get("/calendar/earnings", params=params)
+    def earnings_calendar(self, _from, to, symbol, international=False):
+        return self._get("/calendar/earnings", params={
+            "from": _from,
+            "to": to,
+            "symbol": symbol,
+            "international": international
+        })
 
     def ipo_calendar(self, _from, to):
         return self._get("/calendar/ipo", params={
